import { Resources } from '../types/Pet';
import { putPetCollectResources } from '../services/api/api';

interface CollectResourcesButtonProps {
  petId: string;
  resources: Resources;
  onCollect: () => void;
}

export default function CollectResourcesButton({ petId, resources, onCollect }: CollectResourcesButtonProps) {
  const hasResources = Object.values(resources).some(value => value > 0);

  if (!hasResources) return null;

  const handleCollect = async () => {
    try {
      await putPetCollectResources(petId);
      onCollect();
    } catch (error) {
      console.error('Failed to collect resources:', error);
    }
  };

  return (
    <button
      onClick={handleCollect}
      className="flex items-center justify-center space-x-2
        bg-green-900/30 hover:bg-green-800/50
        border-2 border-green-500/50 rounded-lg p-4
        transition-all duration-300 transform hover:scale-105 w-full mt-2"
    >
      <span>
        Collect: {Object.entries(resources)
          .filter(([_, value]) => value > 0)
          .map(([key, value]) => `${value} ${key}`)
          .join(', ')}
      </span>
    </button>
  );
}
