import { Pet } from '../types/Pet';
import { Brain, Dumbbell, Heart, Sparkles, Coins, Pizza, Trash2 } from 'lucide-react';
import { PET_CLASSES } from '../data/petClasses';

interface PetDisplayProps {
  pet: Pet;
}

export default function PetDisplay({ pet }: PetDisplayProps) {
  const StatBar = ({ value, label, icon: Icon }: { value: number; label: string; icon: any }) => (
    <div className="flex items-center space-x-2">
      <Icon className="w-5 h-5" />
      <div className="flex-1 bg-gray-700 rounded-full h-4">
        <div
          className="bg-blue-500 rounded-full h-4"
          style={{ width: `${value}%` }}
        />
      </div>
      <span className="text-sm">{value}%</span>
    </div>
  );

  const ResourceCounter = ({ value, label, icon: Icon }: { value: number; label: string; icon: any }) => (
    <div className="flex items-center space-x-2 bg-gray-800 rounded-lg p-2">
      <Icon className="w-5 h-5" />
      <span>{label}:</span>
      <span className="font-bold">{value}</span>
    </div>
  );

  return (
    <div className="bg-gray-900 p-6 rounded-xl">
      <div className="text-center mb-8">
        <div className="text-8xl mb-4">{PET_CLASSES[pet.class].emoji}</div>
        <h2 className="text-2xl font-bold">{pet.name}</h2>
        <p className={`text-${PET_CLASSES[pet.class].color}-400`}>
          {PET_CLASSES[pet.class].name}
        </p>
      </div>

      <div className="space-y-4 mb-6">
        <StatBar value={pet.stats.intelligence} label="Intelligence" icon={Brain} />
        <StatBar value={pet.stats.strength} label="Strength" icon={Dumbbell} />
        <StatBar value={pet.stats.charisma} label="Charisma" icon={Heart} />
      </div>

      <div className="grid grid-cols-2 gap-4">
        <ResourceCounter value={pet.resources.wisdom} label="Wisdom" icon={Sparkles} />
        <ResourceCounter value={pet.resources.gold} label="Gold" icon={Coins} />
        <ResourceCounter value={pet.resources.food} label="Food" icon={Pizza} />
        <ResourceCounter value={pet.resources.junk} label="Junk" icon={Trash2} />
      </div>
    </div>
  );
}