// Example usage of the API service
import { ApiService } from './index';
import { Pet } from '../../types/Pet';

// Get API service instance
const api = ApiService.getInstance();

// Example functions using the API service
export async function getPet(id: string) {
  try {
    const response = await api.get<Pet>(`/pets/${id}`);
    return response.data;
  } catch (error: any) {
    if (api.isNetworkError(error)) {
      console.error('Network error occurred');
    } else if (api.isTimeoutError(error)) {
      console.error('Request timed out');
    } else if (api.isServerError(error)) {
      console.error('Server error occurred');
    }
    throw error;
  }
}

export async function updatePet(id: string, data: Partial<Pet>) {
  try {
    const response = await api.put<Pet>(`/pets/${id}`, data);
    return response.data;
  } catch (error: any) {
    console.error('Failed to update pet:', error.message);
    throw error;
  }
}

export async function gatherResources(id: string, resourceType: string) {
  try {
    const response = await api.post<{ success: boolean }>(`/pets/${id}/gather`, {
      resourceType,
    });
    return response.data;
  } catch (error: any) {
    console.error('Failed to gather resources:', error.message);
    throw error;
  }
}